@@ -72,7 +72,7 @@ use namespace::autoclean;
 use utf8;
 
 # ABSTRACT: Test your Dist::Zilla plugin
-our $VERSION = 'v0.3.2'; # VERSION
+our $VERSION = 'v0.3.3'; # VERSION
 
 use Dist::Zilla::Tester::DieHard 0.002;     # DieHard v0.001 rethrows modified exception.
 use File::Temp qw{ tempdir };
@@ -284,17 +284,18 @@ sub _build_tzil {
                 ),
                 map(
                     { (
-                        "source/$_" => ref ( $files->{ $_ } ) ? (
-                            join(
-                                '',
-                                map(
-                                    { ( my $r = $_ ) =~ s{(?<!\n)\z}{\n}x; $r }
-                                    @{ $files->{ $_ } }
+                        "source/$_" =>
+                            ref ( $files->{ $_ } ) ? (
+                                join(
+                                    '',
+                                    map(
+                                        { ( my $r = $_ ) =~ s{(?<!\n)\z}{\n}x; $r }
+                                        @{ $files->{ $_ } }
+                                    )
                                 )
+                            ) : (
+                                $files->{ $_ }
                             )
-                        ) : (
-                            $files->{ $_ }
-                        )
                     ) }
                     keys( %$files ),
                 ),
@@ -534,7 +535,7 @@ Test::Dist::Zilla - Test your Dist::Zilla plugin
 
 =head1 VERSION
 
-Version v0.3.2, released on 2015-09-25 21:42 UTC.
+Version v0.3.3, released on 2015-09-27 17:10 UTC.
 
 =head1 SYNOPSIS
 
