@@ -74,7 +74,7 @@ use warnings;
 use namespace::autoclean;
 
 # ABSTRACT: TODO: Test your Dist::Zilla plugin in I<build> action
-our $VERSION = 'v0.3.2'; # VERSION
+our $VERSION = 'v0.3.3'; # VERSION
 
 use Test::Routine;
 
@@ -132,7 +132,11 @@ test 'BuiltFiles' => sub {
         if ( defined( $exp ) ) {
             ok( $file->exists, "$name exists" ) and do {
                 my $act = ref( $exp ) eq 'ARRAY' ? (
-                    [ $file->lines_utf8( { chomp => 1 } ) ]
+                    #   `$file->lines_utf8( { chomp => 1 } )` does not work as expected in
+                    #   `Path::Tiny` 0.068 .. 0.072 (at least), see
+                    #   <https://github.com/dagolden/Path-Tiny/issues/152>.
+                    #   To workaround the problem, `chomp` lines manually.
+                    [ do { my @l = $file->lines_utf8(); chomp( @l ); @l; } ]
                 ) : (
                     $file->slurp_utf8()
                 );
@@ -176,7 +180,7 @@ Test::Dist::Zilla::BuiltFiles - TODO: Test your Dist::Zilla plugin in I<build> a
 
 =head1 VERSION
 
-Version v0.3.2, released on 2015-09-25 21:42 UTC.
+Version v0.3.3, released on 2015-09-27 17:10 UTC.
 
 =head1 SYNOPSIS
 
